@@ -1,16 +1,7 @@
 //! Filesystem operations.
 
-#[cfg(feature = "fs")]
 mod abs;
 #[cfg(not(target_os = "redox"))]
-#[cfg(any(
-    feature = "fs",
-    feature = "param",
-    feature = "procfs",
-    feature = "runtime",
-    feature = "time",
-    target_arch = "x86"
-))]
 mod at;
 mod constants;
 #[cfg(any(target_os = "android", target_os = "linux"))]
@@ -18,7 +9,6 @@ mod copy_file_range;
 #[cfg(not(target_os = "redox"))]
 mod cwd;
 #[cfg(not(target_os = "redox"))]
-#[cfg(any(feature = "fs", feature = "procfs"))]
 mod dir;
 #[cfg(not(any(
     target_os = "dragonfly",
@@ -58,8 +48,11 @@ mod makedev;
 #[cfg(any(target_os = "android", target_os = "freebsd", target_os = "linux"))]
 mod memfd_create;
 #[cfg(any(target_os = "android", target_os = "linux"))]
-#[cfg(feature = "fs")]
+mod mount;
+#[cfg(any(target_os = "android", target_os = "linux"))]
 mod openat2;
+#[cfg(any(target_os = "android", target_os = "linux"))]
+mod raw_dir;
 #[cfg(target_os = "linux")]
 mod sendfile;
 #[cfg(any(target_os = "android", target_os = "linux"))]
@@ -73,7 +66,6 @@ mod statx;
     target_os = "solaris",
     target_os = "wasi",
 )))]
-#[cfg(feature = "fs")]
 pub use abs::statfs;
 #[cfg(not(any(
     target_os = "haiku",
@@ -82,13 +74,10 @@ pub use abs::statfs;
     target_os = "solaris",
     target_os = "wasi",
 )))]
-#[cfg(feature = "fs")]
 pub use abs::statvfs;
 #[cfg(not(any(target_os = "illumos", target_os = "redox", target_os = "solaris")))]
-#[cfg(feature = "fs")]
 pub use at::accessat;
 #[cfg(any(target_os = "ios", target_os = "macos"))]
-#[cfg(feature = "fs")]
 pub use at::fclonefileat;
 #[cfg(not(any(
     target_os = "ios",
@@ -96,23 +85,12 @@ pub use at::fclonefileat;
     target_os = "redox",
     target_os = "wasi",
 )))]
-#[cfg(feature = "fs")]
 pub use at::mknodat;
 #[cfg(any(target_os = "android", target_os = "linux"))]
-#[cfg(feature = "fs")]
 pub use at::renameat_with;
 #[cfg(not(any(target_os = "redox", target_os = "wasi")))]
-#[cfg(feature = "fs")]
 pub use at::{chmodat, chownat};
 #[cfg(not(target_os = "redox"))]
-#[cfg(any(
-    feature = "fs",
-    feature = "param",
-    feature = "procfs",
-    feature = "runtime",
-    feature = "time",
-    target_arch = "x86"
-))]
 pub use at::{
     linkat, mkdirat, openat, readlinkat, renameat, statat, symlinkat, unlinkat, utimensat, RawMode,
     UTIME_NOW, UTIME_OMIT,
@@ -122,19 +100,16 @@ pub use constants::CloneFlags;
 /// `copyfile_flags_t`
 #[cfg(any(target_os = "ios", target_os = "macos"))]
 pub use constants::CopyfileFlags;
-#[cfg(any(target_os = "android", target_os = "linux"))]
-pub use constants::RenameFlags;
-#[cfg(any(target_os = "android", target_os = "linux"))]
-pub use constants::ResolveFlags;
 pub use constants::{Access, FdFlags, Mode, Nsecs, OFlags, Secs, Timespec};
 #[cfg(not(target_os = "redox"))]
 pub use constants::{AtFlags, Dev};
 #[cfg(any(target_os = "android", target_os = "linux"))]
+pub use constants::{MountFlags, MountPropagationFlags, RenameFlags, ResolveFlags};
+#[cfg(any(target_os = "android", target_os = "linux"))]
 pub use copy_file_range::copy_file_range;
 #[cfg(not(target_os = "redox"))]
 pub use cwd::cwd;
 #[cfg(not(target_os = "redox"))]
-#[cfg(any(feature = "fs", feature = "procfs"))]
 pub use dir::{Dir, DirEntry};
 #[cfg(not(any(
     target_os = "dragonfly",
@@ -227,8 +202,11 @@ pub use makedev::{major, makedev, minor};
 #[cfg(any(target_os = "android", target_os = "freebsd", target_os = "linux"))]
 pub use memfd_create::{memfd_create, MemfdFlags};
 #[cfg(any(target_os = "android", target_os = "linux"))]
-#[cfg(feature = "fs")]
+pub use mount::{bind_mount, change_mount, mount, move_mount, recursive_bind_mount, remount};
+#[cfg(any(target_os = "android", target_os = "linux"))]
 pub use openat2::openat2;
+#[cfg(any(target_os = "android", target_os = "linux"))]
+pub use raw_dir::{RawDir, RawDirEntry};
 #[cfg(target_os = "linux")]
 pub use sendfile::sendfile;
 #[cfg(any(target_os = "android", target_os = "linux"))]
